@@ -1,36 +1,37 @@
 import logging
-from collections import namedtuple
 import os.path
+from collections import namedtuple
+from itertools import product
 from datetime import datetime as dt
+from pathlib import Path
+
+
+import configsuite
+import yaml
+import xtgeo
 import numpy as np
 from scipy.interpolate import CloughTocher2DInterpolator
-
 from ecl.grid import EclGrid
 from ecl.gravimetry import EclSubsidence
 from ecl.eclfile import Ecl3DKW, EclFile
 
-from ecl.util.geometry import Surface
-
 from semeio.jobs.overburden_timeshift.ots_vel_surface import OTSVelSurface
 from semeio.jobs.overburden_timeshift.ots_res_surface import OTSResSurface
 from semeio.jobs.overburden_timeshift.ots_config import build_schema
 from semeio._exceptions.exceptions import ConfigurationError
-import configsuite
-import yaml
 
 
 # pylint: disable=consider-using-enumerate
 def extract_ots_context(configuration):
-    if configuration.eclbase is not None:
-        rstfile_path = "{}.UNRST".format(configuration.eclbase)
-        rstfile = EclFile(rstfile_path)
-        dates = [d.date() for d in rstfile.dates]
-        return dates
-    return []
+    rstfile_path = Path(f"{configuration.eclbase}.UNRST")
+    if not rstfile_path.exists():
+        return []
+    dates = [d.date() for d in EclFile(str(rstfile_path)).dates]
+    return dates
 
 
 def ots_load_params(input_file):
-    with open(input_file, "r") as fin:
+    with open(input_file, "r", encoding="utf-8") as fin:
         config = yaml.safe_load(fin)
     config = configsuite.ConfigSuite(
         config,
@@ -40,7 +41,7 @@ def ots_load_params(input_file):
     )
     if not config.valid:
         raise ConfigurationError(
-            "Invalid configuration for config file: {}".format(input_file),
+            f"Invalid configuration for config file: {input_file}",
             config.errors,
         )
 
@@ -48,11 +49,14 @@ def ots_load_params(input_file):
     return input_data
 
 
-def write_surface(vintage_pairs, ts, output_dir, type_str):
+def write_surface(vintage_pairs, ts, output_dir, type_str, file_format="irap_binary"):
+    output_path = Path(output_dir + type_str)
+    if not output_path.is_dir():
+        output_path.mkdir()
     for iv, vp in enumerate(vintage_pairs):
         d0 = vp[0].strftime("%Y_%m_%d")
         d1 = vp[1].strftime("%Y_%m_%d")
-        ts[iv].write(output_dir + type_str + "/ots" + "_" + d0 + "_" + d1 + ".irap")
+        ts[iv].to_file(output_path / f"ots_{d0}_{d1}.irap", fformat=file_format)
 
 
 def ots_run(parameter_file):
@@ -79,17 +83,37 @@ def ots_run(parameter_file):
 
     surface_horizon = ots.get_horizon()
 
-    write_surface(vintage_pairs.ts, tshift_ts, parms.output_dir, "_ts")
     write_surface(
-        vintage_pairs.ts_simple, tshift_ts_simple, parms.output_dir, "_ts_simple"
+        vintage_pairs.ts,
+        tshift_ts,
+        parms.output_dir,
+        "_ts",
+        file_format=parms.file_format,
     )
-    write_surface(vintage_pairs.dpv, tshift_dpv, parms.output_dir, "_dpv")
     write_surface(
-        vintage_pairs.ts_rporv, tshift_ts_rporv, parms.output_dir, "_ts_rporv"
+        vintage_pairs.ts_simple,
+        tshift_ts_simple,
+        parms.output_dir,
+        "_ts_simple",
+        file_format=parms.file_format,
+    )
+    write_surface(
+        vintage_pairs.dpv,
+        tshift_dpv,
+        parms.output_dir,
+        "_dpv",
+        file_format=parms.file_format,
+    )
+    write_surface(
+        vintage_pairs.ts_rporv,
+        tshift_ts_rporv,
+        parms.output_dir,
+        "_ts_rporv",
+        file_format=parms.file_format,
     )
 
     if parms.horizon is not None:
-        surface_horizon.write(parms.horizon)
+        surface_horizon.to_file(parms.horizon)
 
     if parms.vintages_export_file is not None:
         num_pairs = (
@@ -99,19 +123,34 @@ def ots_run(parameter_file):
             + len(vintage_pairs.ts_rporv)
         )
         line = "{}, {}, {}" + ", {}" * num_pairs + "\n"
-        with open(parms.vintages_export_file, "w") as f:
-            for point in range(len(surface_horizon)):
-                xy = surface_horizon.getXY(point)
+        with open(parms.vintages_export_file, "w", encoding="utf-8") as f:
+
+            for point, (x_index, y_index) in enumerate(
+                product(
+                    range(1, surface_horizon.get_nx() + 1),
+                    range(1, surface_horizon.get_ny() + 1),
+                )
+            ):
+                x_cord, y_cord, _ = surface_horizon.get_xy_value_from_ij(
+                    x_index, y_index
+                )
                 ts = []
                 for iv in range(len(vintage_pairs.ts)):
                     ts.append(tshift_ts[iv][point])
                 for iv in range(len(vintage_pairs.ts_simple)):
-                    ts.append(tshift_ts_simple[iv][point])
+                    ts.append(tshift_ts_simple[iv].get_value_from_xy((x_cord, y_cord)))
                 for iv in range(len(vintage_pairs.dpv)):
-                    ts.append(tshift_dpv[iv][point])
+                    ts.append(tshift_dpv[iv].get_value_from_xy((x_cord, y_cord)))
                 for iv in range(len(vintage_pairs.ts_rporv)):
-                    ts.append(tshift_ts_rporv[iv][point])
-                f.write(line.format(xy[0], xy[1], surface_horizon[point], *ts))
+                    ts.append(tshift_ts_rporv[iv].get_value_from_xy((x_cord, y_cord)))
+                f.write(
+                    line.format(
+                        x_cord,
+                        y_cord,
+                        surface_horizon.get_value_from_xy((x_cord, y_cord)),
+                        *ts,
+                    )
+                )
 
 
 class OverburdenTimeshift(object):
@@ -138,9 +177,9 @@ class OverburdenTimeshift(object):
         overburden timeshift calculations.
         """
         case = os.path.splitext(eclbase)[0]
-        self._init_file = EclFile("%s.INIT" % case)
-        self._rst_file = EclFile("%s.UNRST" % case)
-        self._grid = EclGrid("%s.EGRID" % case, apply_mapaxes=mapaxes)
+        self._init_file = EclFile(f"{case}.INIT")
+        self._rst_file = EclFile(f"{case}.UNRST")
+        self._grid = EclGrid(f"{case}.EGRID", apply_mapaxes=mapaxes)
 
         self.subsidence = EclSubsidence(self._grid, self._init_file)
 
@@ -172,8 +211,8 @@ class OverburdenTimeshift(object):
         if z is None:
             z = self._surface.z
 
-        xstart = np.min(x)
-        ystart = np.min(y)
+        xstart = float(np.min(x))  # Casting to float for xtgeo
+        ystart = float(np.min(y))  # Casting to float for xtgeo
 
         if nx < 2 or ny < 2:
             raise RuntimeError("Cannot create IRAP surface if nx or ny is <2")
@@ -181,25 +220,34 @@ class OverburdenTimeshift(object):
         xinc = (np.max(x) - xstart) / (nx - 1)
         yinc = (np.max(y) - ystart) / (ny - 1)
 
-        surf = Surface(
-            nx=nx, ny=ny, xinc=xinc, yinc=yinc, xstart=xstart, ystart=ystart, angle=0
+        surf_geo = xtgeo.RegularSurface(
+            ncol=nx,
+            nrow=ny,
+            xori=xstart,
+            yori=ystart,
+            xinc=xinc,
+            yinc=yinc,
+            rotation=0,
         )
 
         irap_x = np.empty(nx * ny)
         irap_y = np.array(irap_x)
 
-        for i in range(len(surf)):
-            irap_x[i], irap_y[i] = surf.getXY(i)
+        for counter, (x_index, y_index) in enumerate(
+            product(range(1, nx + 1), range(1, ny + 1))
+        ):
+            irap_x[counter], irap_y[counter], _ = surf_geo.get_xy_value_from_ij(
+                x_index, y_index
+            )
 
         # Interpolate vel grid to irap grid, should be the same apart from ordering
         z = np.nan_to_num(z)
         ip = CloughTocher2DInterpolator((x, y), z, fill_value=0)
         irap_z = ip(irap_x, irap_y)
 
-        for i in range(len(surf)):
-            surf[i] = irap_z[i]
+        surf_geo.set_zval(irap_z)
 
-        return surf
+        return surf_geo
 
     def add_survey(self, name, date):
         """The add_survey() method will register a survey at a specific date.
@@ -266,7 +314,7 @@ class OverburdenTimeshift(object):
         ts_surfaces = []
         for vintage in vintages:
             logging.info(
-                "{:%x %X} {}: Calculating vintage {:%Y.%m.%d}".format(
+                "{:%x %X} {}: Calculating vintage {:%Y.%m.%d}".format(  # pylint: disable=consider-using-f-string
                     dt.now(), method_name, vintage.date
                 )
             )
@@ -339,7 +387,7 @@ class OverburdenTimeshift(object):
         for base, monitor in vintage_pairs:
             surf_displacement = np.zeros(len(surface))
             logging.info(
-                "{:%x %X} TS: Calculating vintage"
+                "{:%x %X} TS: Calculating vintage"  # pylint: disable=consider-using-f-string
                 " {:%Y.%m.%d} - {:%Y.%m.%d}".format(dt.now(), base, monitor)
             )
 
@@ -400,7 +448,7 @@ class OverburdenTimeshift(object):
         vintages_date = list(vintages)
         vintages_name = []
         for i in range(len(vintages_date)):
-            vintages_name.append("S{}".format(i))
+            vintages_name.append(f"S{i}")
 
         Vintage = namedtuple("Vintages", "name date")
         return [Vintage(name, date) for name, date in zip(vintages_name, vintages_date)]
@@ -411,11 +459,9 @@ class OverburdenTimeshift(object):
         elif self._convention == -1:
             start_date, end_date = base, monitor
         else:
-            raise ValueError(
-                "Convention must be 1 or -1, was {}".format(self._convention)
-            )
+            raise ValueError(f"Convention must be 1 or -1, was {self._convention}")
         logging.debug(
-            "{:%x %X} {}: Calculating shift"
+            "{:%x %X} {}: Calculating shift"  # pylint: disable=consider-using-f-string
             " {:%Y.%m.%d}-{:%Y.%m.%d} in {} points".format(
                 dt.now(), func_name, start_date, end_date, num_points_calculated
             )
@@ -462,7 +508,7 @@ class OverburdenTimeshift(object):
 
         for vintage in vintages:
             logging.info(
-                "{:%x %X} DPV: Calculating vintage"
+                "{:%x %X} DPV: Calculating vintage"  # pylint: disable=consider-using-f-string
                 " {:%Y.%m.%d}".format(dt.now(), vintage.date)
             )
             self.add_survey(vintage.name, vintage.date)
