@@ -1,4 +1,3 @@
-import argparse
 import os
 
 import pandas as pd
@@ -87,17 +86,17 @@ class TrajectoryPoint:
             str
         """
         if self.grid_ijk is None:
-            return "TRAJECTORY_POINT_NOT_IN_GRID {}".format(str(self))
+            return f"TRAJECTORY_POINT_NOT_IN_GRID {str(self)}"
         if self.pressure is None:
-            return "TRAJECTORY_POINT_NOT_IN_RFT {}".format(str(self))
+            return f"TRAJECTORY_POINT_NOT_IN_RFT {str(self)}"
         if not self.valid_zone and zonemap is not None:
             if self.grid_ijk[2] not in zonemap:
-                return "ZONEMAP_MISSING_VALUE {} {} {}".format(
-                    str(self), self.grid_ijk[2], None
-                )
+                return f"ZONEMAP_MISSING_VALUE {str(self)} {self.grid_ijk[2]} {None}"
 
-            return "ZONE_MISMATCH {} {} {}".format(
-                str(self), self.grid_ijk[2], zonemap[self.grid_ijk[2]]
+            return (
+                f"ZONE_MISMATCH {str(self)} "
+                f"{self.grid_ijk[2]} "
+                f"{zonemap[self.grid_ijk[2]]}"
             )
 
     def get_pressure(self):
@@ -139,8 +138,10 @@ class TrajectoryPoint:
                         self.soil = 1 - self.swat
 
     def __str__(self):
-        return "(utm_x={utm_x}, utm_y={utm_y}, measured_depth={measured_depth})".format(
-            utm_x=self.utm_x, utm_y=self.utm_y, measured_depth=self.measured_depth
+        return (
+            f"(utm_x={self.utm_x}, "
+            f"utm_y={self.utm_y}, "
+            f"measured_depth={self.measured_depth})"
         )
 
 
@@ -221,9 +222,7 @@ class Trajectory:
         tuplelengths = {len(value) for value in dframe.loc[non_nulls, tuplecolumn]}
         if len(tuplelengths) != 1:
             raise ValueError(
-                "Uneven tuple lengths {} in non-null dataframe data".format(
-                    tuplelengths
-                )
+                f"Uneven tuple lengths {tuplelengths} in non-null dataframe data"
             )
         if list(tuplelengths)[0] != len(components):
             raise ValueError("Mismatch between tuple length and given column names")
@@ -250,7 +249,7 @@ class Trajectory:
         """
         point = line.split()
         if len(point) < 4 or len(point) > 5:
-            raise argparse.ArgumentTypeError(
+            raise ValueError(
                 (
                     "Trajectory data file not on correct format: "
                     "'utm_x utm_y md tvd <zone>' - zone is optional"
@@ -259,10 +258,12 @@ class Trajectory:
 
         try:
             floats = [float(v) for v in point[:4]]
-        except ValueError:
-            raise argparse.ArgumentTypeError(
-                "Error: Failed to extract data from line {line}".format(line=line)
-            )
+        except ValueError as err:
+            raise ValueError(
+                f"Error: Failed to extract data from line {line}. Expected the format "
+                "'utm_x utm_y md tvd zone' - zone is optional, where utm coordinates, "
+                "md and tvd are numbers"
+            ) from err
 
         zone = point[4].strip() if len(point) == 5 else None
         return floats + [zone]
@@ -274,13 +275,9 @@ class Trajectory:
 
         filename = os.path.join(filepath)
         if not os.path.isfile(filename):
-            raise argparse.ArgumentTypeError(
-                "Warning: Trajectory file {filename} not found!".format(
-                    filename=filename
-                )
-            )
+            raise IOError(f"Trajectory file {filename} not found!")
 
-        with open(filename, "r") as f:
+        with open(filename, "r", encoding="utf8") as f:
             trajectory_lines = f.readlines()
 
         trajectory_lines = [strip_comments(line) for line in trajectory_lines]
