@@ -34,8 +34,7 @@ def _update_scaling(obs, scale_factor, obs_list):
                     obs_node.set_std_scaling(scale_factor)
             else:
                 obs_node.updateStdScaling(scale_factor, event.active_list)
-    logging.info(
-        "Keys: {} scaled with scaling factor: {}".format(
-            [event.key for event in obs_list], scale_factor
-        )
+    logging.info(  # pylint: disable=logging-fstring-interpolation
+        f"Keys: {[event.key for event in obs_list]} scaled "
+        f"with scaling factor: {scale_factor}"
     )
