@@ -49,14 +49,14 @@ def _fetch_config_record(args):
     if len(args) == 0:
         return {}
     elif len(args) == 1:
-        with open(args[0]) as f:
+        with open(args[0], encoding="utf8") as f:
             return yaml.safe_load(f)
     else:
         raise ValueError(
             (
                 "Excepted at most one argument, namely the path to a "
-                "configuration file. Received {} arguments: {}"
-            ).format(len(args), args)
+                f"configuration file. Received {len(args)} arguments: {args}"
+            )
         )
 
 
