@@ -1,17 +1,18 @@
 # -*- coding: utf-8 -*-
+# pylint: disable=logging-fstring-interpolation
 import itertools
 import logging
-from scipy.cluster.hierarchy import fcluster, linkage
+
+from semeio.workflows.spearman_correlation_job.cluster_analysis import (
+    fcluster_analysis,
+)
 
 
 def spearman_job(
     measured_data,
-    threshold,
     reporter,
-    criterion="inconsistent",
-    depth=2,
-    method="single",
-    metric="euclidean",
+    cluster_function=fcluster_analysis,
+    **cluster_args,
 ):
     """
     Given measured_data and threshold, it returns configurations that describe
@@ -25,9 +26,7 @@ def spearman_job(
     correlation_matrix = _calculate_correlation_matrix(simulated_data)
     reporter.publish_csv("correlation_matrix", correlation_matrix)
 
-    clusters = _cluster_analysis(
-        correlation_matrix, threshold, criterion, depth, method, metric
-    )
+    clusters = cluster_function(correlation_matrix, **cluster_args)
 
     columns = correlation_matrix.columns
 
@@ -48,7 +47,7 @@ def spearman_job(
     job_configs = _config_creation(clustered_data)
 
     for cluster, val in clustered_data.items():
-        logging.info("Cluster nr: {}, clustered data: {}".format(cluster, val))
+        logging.info(f"Cluster nr: {cluster}, clustered data: {val}")
 
     return job_configs
 
@@ -73,9 +72,7 @@ def _remove_singular_obs(clusters):
             multiobs_clusters[new_cluster_index] = cluster
             new_cluster_index += 1
         else:
-            logging.info(
-                "Removed cluster with singular observation: {}".format(cluster)
-            )
+            logging.info(f"Removed cluster with singular observation: {cluster}")
     return multiobs_clusters
 
 
@@ -97,8 +94,3 @@ def _calculate_correlation_matrix(data):
     # of pandas (https://github.com/pandas-dev/pandas/pull/28151), for now this is
     # equivalent:
     return data.rank().corr(method="pearson")
-
-
-def _cluster_analysis(correlation_matrix, threshold, criterion, depth, method, metric):
-    a = linkage(correlation_matrix, method, metric)
-    return fcluster(a, threshold, criterion=criterion, depth=depth)
