@@ -6,7 +6,9 @@ import semeio.hook_implementations.jobs
 from semeio.workflows.misfit_preprocessor import misfit_preprocessor
 from semeio.workflows.spearman_correlation_job import spearman_correlation
 from semeio.workflows.correlated_observations_scaling import cos
+from semeio.workflows.localisation import local_config_script
 from semeio.workflows.csv_export2 import csv_export2
+from semeio.workflows.ahm_analysis import ahmanalysis
 from ert_shared.plugins.plugin_manager import ErtPluginManager
 
 
@@ -17,19 +19,21 @@ def test_hook_implementations():
             spearman_correlation,
             misfit_preprocessor,
             cos,
+            local_config_script,
             csv_export2,
+            ahmanalysis,
         ]
     )
 
     expected_jobs = {
-        "DESIGN_KW": "semeio/jobs/config_jobs/DESIGN_KW",
-        "DESIGN2PARAMS": "semeio/jobs/config_jobs/DESIGN2PARAMS",
-        "STEA": "semeio/jobs/config_jobs/STEA",
-        "GENDATA_RFT": "semeio/jobs/config_jobs/GENDATA_RFT",
-        "PYSCAL": "semeio/jobs/config_jobs/PYSCAL",
-        "INSERT_NOSIM": "semeio/jobs/config_jobs/INSERT_NOSIM",
-        "REMOVE_NOSIM": "semeio/jobs/config_jobs/REMOVE_NOSIM",
-        "OTS": "semeio/jobs/config_jobs/OTS",
+        "DESIGN_KW": "semeio/jobs/config_jobs/DESIGN_KW_CONFIG",
+        "DESIGN2PARAMS": "semeio/jobs/config_jobs/DESIGN2PARAMS_CONFIG",
+        "STEA": "semeio/jobs/config_jobs/STEA_CONFIG",
+        "GENDATA_RFT": "semeio/jobs/config_jobs/GENDATA_RFT_CONFIG",
+        "PYSCAL": "semeio/jobs/config_jobs/PYSCAL_CONFIG",
+        "INSERT_NOSIM": "semeio/jobs/config_jobs/INSERT_NOSIM_CONFIG",
+        "REMOVE_NOSIM": "semeio/jobs/config_jobs/REMOVE_NOSIM_CONFIG",
+        "OTS": "semeio/jobs/config_jobs/OTS_CONFIG",
     }
     installable_jobs = pm.get_installable_jobs()
     for wf_name, wf_location in expected_jobs.items():
@@ -43,6 +47,8 @@ def test_hook_implementations():
         "SPEARMAN_CORRELATION",
         "CSV_EXPORT2",
         "MISFIT_PREPROCESSOR",
+        "AHM_ANALYSIS",
+        "LOCALISATION_JOB",
     ]
     installable_workflow_jobs = pm.get_installable_workflow_jobs()
     for wf_name, wf_location in installable_workflow_jobs.items():
