@@ -1,7 +1,6 @@
 import filecmp
 import logging
 import os
-from packaging import version
 from distutils.dir_util import copy_tree
 
 import pandas as pd
@@ -9,6 +8,7 @@ import pytest
 
 from semeio.jobs.design2params import design2params
 from semeio.jobs.design_kw.design_kw import extract_key_value
+from semeio._exceptions.exceptions import ValidationError
 
 
 @pytest.fixture
@@ -45,7 +45,7 @@ def test_run(test_file, expected_file):
 
     assert filecmp.cmp(test_file, expected_file)
 
-    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
+    with open(design2params._TARGET_FILE_TXT, "r", encoding="utf-8") as status_file:
         status = status_file.read()
         assert status == "OK\n"
 
@@ -71,7 +71,7 @@ def test_run_with_no_parameters_txt(test_file, expected_file):
 
     assert filecmp.cmp(test_file, expected_file)
 
-    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
+    with open(design2params._TARGET_FILE_TXT, "r", encoding="utf-8") as status_file:
         status = status_file.read()
         assert status == "OK\n"
 
@@ -97,7 +97,7 @@ def test_run_with_default(test_file, expected_file):
 
     assert filecmp.cmp(test_file, expected_file)
 
-    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
+    with open(design2params._TARGET_FILE_TXT, "r", encoding="utf-8") as status_file:
         status = status_file.read()
         assert status == "OK\n"
 
@@ -123,7 +123,7 @@ def test_run_with_spaces_in_cells(test_file, expected_file):
 
     assert filecmp.cmp(test_file, expected_file)
 
-    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
+    with open(design2params._TARGET_FILE_TXT, "r", encoding="utf-8") as status_file:
         status = status_file.read()
         assert status == "OK\n"
 
@@ -138,7 +138,7 @@ def test_runs_different_reals_all_ok(realization_id):
         log_level=logging.DEBUG,
     )
 
-    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
+    with open(design2params._TARGET_FILE_TXT, "r", encoding="utf-8") as status_file:
         status = status_file.read()
         assert status == "OK\n"
 
@@ -205,7 +205,10 @@ def test_open_excel_file_not_xls(input_data):
 
 
 def test_open_excel_file_header_missing(input_data):
-    with pytest.raises(SystemExit):
+    with pytest.raises(
+        ValidationError,
+        match="Design matrix not valid, error: Column headers not present in column",
+    ):
         design2params.run(
             1,
             "design_matrix_missing_header.xlsx",
@@ -267,7 +270,7 @@ def test_existing_parameterstxt(
     tmpdir.chdir()
 
     params_file = "parameters.txt"
-    with open(params_file, "w") as file_h:
+    with open(params_file, "w", encoding="utf-8") as file_h:
         file_h.write(exist_params)
 
     designsheet_df = pd.DataFrame.from_records(data=[design_m])
@@ -339,7 +342,7 @@ def test_single_cell_values(cellvalue, expected_parameters_str, tmpdir):
         parametersfilename=params_file,
         log_level=logging.DEBUG,
     )
-    with open(params_file) as p_file:
+    with open(params_file, encoding="utf-8") as p_file:
         params_lines = p_file.readlines()
     key_vals = extract_key_value(params_lines)
     assert key_vals["SOMEKEY"] == expected_parameters_str
@@ -386,9 +389,9 @@ def test_pair_cell_values(cellvalues, expected_parameters_strs, tmpdir):
         parametersfilename=params_1,
         log_level=logging.DEBUG,
     )
-    with open(params_0) as p_file:
+    with open(params_0, encoding="utf-8") as p_file:
         params_lines_0 = p_file.readlines()
-    with open(params_1) as p_file:
+    with open(params_1, encoding="utf-8") as p_file:
         params_lines_1 = p_file.readlines()
     key_vals_real0 = extract_key_value(params_lines_0)
     key_vals_real1 = extract_key_value(params_lines_1)
@@ -433,11 +436,7 @@ def test_headers_trailing_whitespace(paramnames, tmpdir):
             0,
             "design_matrix.xlsx",
         )
-    if version.parse(pd.__version__) < version.parse("0.25"):
-        expected_error = "Invalid value in design matrix header"
-    else:
-        expected_error = "whitespace"
-    with pytest.raises(SystemExit, match=expected_error):
+    with pytest.raises(SystemExit, match="whitespace"):
         design2params.run(
             0,
             "design_matrix_onlydefaults.xlsx",
@@ -471,11 +470,7 @@ def test_denylist_defaults(paramname, tmpdir):
     write_design_xlsx(
         "design_matrix.xlsx", defaultsdf=pd.DataFrame(data=[[paramname, "bar"]])
     )
-    if version.parse(pd.__version__) < version.parse("0.25"):
-        expected_error = "Invalid value in design matrix header"
-    else:
-        expected_error = "not allowed"
-    with pytest.raises(SystemExit, match=expected_error):
+    with pytest.raises(SystemExit, match="not allowed"):
         design2params.run(
             0,
             "design_matrix.xlsx",
@@ -492,7 +487,7 @@ def test_invalid_pandas_header_error(tmpdir, paramname):
     )
 
     expected_error = "Invalid value in design matrix header"
-    with pytest.raises(SystemExit, match=expected_error):
+    with pytest.raises(ValidationError, match=expected_error):
         design2params.run(
             0,
             "design_matrix.xlsx",
@@ -505,11 +500,7 @@ def test_denylist_expected_error(paramname, tmpdir):
     write_design_xlsx(
         "design_matrix.xlsx", defaultsdf=pd.DataFrame(data=[[paramname, "bar"]])
     )
-    if version.parse(pd.__version__) < version.parse("0.25"):
-        expected_error = "Invalid value in design matrix header"
-    else:
-        expected_error = "does not exist in design matrix"
-    with pytest.raises(SystemExit, match=expected_error):
+    with pytest.raises(SystemExit, match="does not exist in design matrix"):
         design2params.run(
             0,
             "design_matrix.xlsx",
@@ -539,6 +530,21 @@ def test_duplicated_designcolumns(paramset, tmpdir, caplog):
     assert "are probably duplicated" in caplog.text
 
 
+def test_equal_sheetargs(tmpdir):
+    """The dataframes for design sheet and defaults have a different structure
+    and cannot be allowed to be mixed"""
+    tmpdir.chdir()
+    write_design_xlsx(
+        "dummy.xlsx",
+        designdf=pd.DataFrame(columns=["COM", "FOO"], data=[[0, "BAR"]]),
+        designsheetname="foo",
+    )
+    with pytest.raises(SystemExit):
+        design2params.run(
+            0, "dummy.xlsx", designsheetname="foo", defaultssheetname="foo"
+        )
+
+
 def write_design_xlsx(
     filename,
     designdf=None,
