@@ -9,7 +9,13 @@ import semeio.hook_implementations.jobs
 import ert_shared.hook_implementations
 
 
-@pytest.mark.skipif(sys.platform == "darwin", reason="Skip test for Mac OS")
+@pytest.mark.skipif(
+    sys.platform == "darwin", reason="Skip test for Mac OS - invalid use of sed"
+)
+# The GNU extension for the sed command on osx behaves slightly different.
+# The result when running the forward model job is as follow:
+# cat insert_nosim.stderr.1
+# sed: 1: "TEST.DATA": invalid command code T
 @pytest.mark.parametrize(
     "nosim_command,data_input,data_expected",
     [
@@ -57,22 +63,17 @@ import ert_shared.hook_implementations
 def test_nosim(setup_tmpdir, nosim_command, data_input, data_expected):
     shutil.copy(os.path.join(os.path.dirname(__file__), "data", "nosim.ert"), ".")
 
-    with open("nosim.ert", "a") as fh:
-        fh.writelines(["FORWARD_MODEL {}".format(nosim_command)])
+    with open("nosim.ert", "a", encoding="utf-8") as fh:
+        fh.writelines([f"FORWARD_MODEL {nosim_command}"])
 
-    with open("TEST.DATA", "w") as fh:
+    with open("TEST.DATA", "w", encoding="utf-8") as fh:
         fh.write(data_input)
 
     with ErtPluginContext(
         plugins=[semeio.hook_implementations.jobs, ert_shared.hook_implementations]
     ):
-        p = subprocess.Popen(
+        subprocess.check_call(
             ["ert", "test_run", "nosim.ert", "--verbose"],
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            env=os.environ.copy(),
         )
-        p.wait()
-
-    with open("nosim/real_0/iter_0/TEST.DATA") as fh:
+    with open("nosim/real_0/iter_0/TEST.DATA", encoding="utf-8") as fh:
         assert fh.read() == data_expected
