@@ -1,3 +1,4 @@
+# pylint: disable=not-callable
 import os
 import shutil
 import json
@@ -26,7 +27,8 @@ def test_main_entry_point_gen_data(monkeypatch, test_data_root):
 
     res_config = ResConfig("snake_oil.ert")
     ert = EnKFMain(res_config)
-    sc.SpearmanCorrelationJob(ert).run(*["-t", "1.0"])
+    job = sc.SpearmanCorrelationJob(ert)
+    job.run(*["-t", "1.0"])
 
     # call_args represents the clusters, we expect the snake_oil
     # observations to generate this amount of them
@@ -35,12 +37,18 @@ def test_main_entry_point_gen_data(monkeypatch, test_data_root):
     # again is a tuple containing the configuration which is a list of configs.
     assert len(list(run_mock.call_args)[0][0]) == 47, "wrong number of clusters"
 
-    cor_matrix_file = "reports/snake_oil/SpearmanCorrelationJob/correlation_matrix.csv"
+    cor_matrix_file = os.path.join(
+        job._output_dir,
+        "correlation_matrix.csv",
+    )
 
     pd.read_csv(cor_matrix_file, index_col=[0, 1], header=[0, 1])
 
-    clusters_file = "reports/snake_oil/SpearmanCorrelationJob/clusters.json"
-    with open(clusters_file) as f:
+    clusters_file = os.path.join(
+        job._output_dir,
+        "clusters.json",
+    )
+    with open(clusters_file, encoding="utf-8") as f:
         cluster_reports = json.load(f)
         assert len(cluster_reports) == 1
 
@@ -127,16 +135,22 @@ def test_main_entry_point_syn_data(monkeypatch, facade, measured_data):
     monkeypatch.setattr(sc, "MeasuredData", md_mock)
 
     resconfig_mock = Mock()
-    resconfig_mock.config_path = "config_path"
-    resconfig_mock.user_config_file = "user_config_file"
+    resconfig_mock.model_config.getEnspath.return_value = os.path.join(
+        "config_path", "storage_path"
+    )
 
-    ert_mock = Mock(resConfig=Mock(return_value=resconfig_mock))
+    ert_mock = Mock()
+    fs_mock = Mock()
+    fs_mock.return_value.getCaseName.return_value = "user_case_name"
+    ert_mock.getEnkfFsManager.return_value.getCurrentFileSystem = fs_mock
+    ert_mock.resConfig.return_value = resconfig_mock
+    resconfig_mock.user_config_file = "config_name"
 
-    sc.SpearmanCorrelationJob(ert_mock).run(*["-t", "1.0"])
-
-    cor_matrix_file = (
-        "config_path/reports/user_config_file/"
-        "SpearmanCorrelationJob/correlation_matrix.csv"
+    job = sc.SpearmanCorrelationJob(ert_mock)
+    job.run(*["-t", "1.0"])
+    cor_matrix_file = os.path.join(
+        job._output_dir,
+        "correlation_matrix.csv",
     )
 
     r1 = [1, 5, 3]
@@ -153,10 +167,11 @@ def test_main_entry_point_syn_data(monkeypatch, facade, measured_data):
     corr_matrix = pd.read_csv(cor_matrix_file, index_col=[0, 1], header=[0, 1])
 
     assert (expected_corr_matrix == corr_matrix.values).all()
-    clusters_file = (
-        "config_path/reports/user_config_file/SpearmanCorrelationJob/clusters.json"
+    clusters_file = os.path.join(
+        job._output_dir,
+        "clusters.json",
     )
-    with open(clusters_file) as f:
+    with open(clusters_file, encoding="utf-8") as f:
         cluster_reports = json.load(f)
         assert len(cluster_reports) == 1
 
