@@ -1,11 +1,8 @@
 #!/usr/bin/env python
+# pylint: disable=too-many-statements,consider-using-f-string
 from datetime import datetime
-import os
-import sys
 
-from ecl.summary import EclSum, EclSumTStep
-from ecl.util.test import ExtendedTestCase
-import res
+from ecl.summary import EclSum
 
 from res.test.synthesizer import OilSimulator
 
@@ -25,7 +22,7 @@ def readParameters(filename):
 
 
 def runSimulator(simulator, history_simulator, time_step_count):
-    """ @rtype: EclSum """
+    """@rtype: EclSum"""
     ecl_sum = EclSum.writer("SNAKE_OIL_FIELD", datetime(2010, 1, 1), 10, 10, 10)
 
     ecl_sum.addVariable("FOPT")
@@ -77,7 +74,9 @@ def runSimulator(simulator, history_simulator, time_step_count):
 
     for report_step in range(time_step_count):
         for mini_step in range(mini_step_count):
-            t_step = ecl_sum.addTStep(report_step + 1, sim_days=report_step * mini_step_count + mini_step)
+            t_step = ecl_sum.addTStep(
+                report_step + 1, sim_days=report_step * mini_step_count + mini_step
+            )
 
             time_map.append(t_step.getSimTime().datetime().strftime("%d/%m/%Y"))
 
@@ -142,7 +141,7 @@ def roundedInt(value):
     return int(round(float(value)))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     seed = int(readParameters("seed.txt")["SEED"])
     parameters = readParameters("snake_oil_params.txt")
 
@@ -159,8 +158,22 @@ if __name__ == '__main__':
     op2_octaves = roundedInt(parameters["OP2_OCTAVES"])
 
     simulator = OilSimulator()
-    simulator.addWell("OP1", seed * 997, persistence=op1_persistence, octaves=op1_octaves, divergence_scale=op1_divergence_scale, offset=op1_offset)
-    simulator.addWell("OP2", seed * 13, persistence=op2_persistence, octaves=op2_octaves, divergence_scale=op2_divergence_scale, offset=op2_offset)
+    simulator.addWell(
+        "OP1",
+        seed * 997,
+        persistence=op1_persistence,
+        octaves=op1_octaves,
+        divergence_scale=op1_divergence_scale,
+        offset=op1_offset,
+    )
+    simulator.addWell(
+        "OP2",
+        seed * 13,
+        persistence=op2_persistence,
+        octaves=op2_octaves,
+        divergence_scale=op2_divergence_scale,
+        offset=op2_offset,
+    )
     simulator.addBlock("5,5,5", seed * 37, persistence=bpr_555_persistence)
     simulator.addBlock("1,3,8", seed * 31, persistence=bpr_138_persistence)
 
